==> OpenOLAP_V1.0.1.zip: OpenOLAP/src/viewer/target/spread/js/cellColor.js <==

// *************************************************************************************************
// FẪf[^\
//	EZ(TDIuWFNg)̑
//		<TD object>.selected: ZIĂ"1"AIĂȂ"0"BԂł͑ȂB
//		<TD object>.colorName: ZɂĂF̖(FuRedv,uPurplevetc)
//		<TD object>.style.backgroundColor: ۂɃZɂĂFiAzz擾j 
//	EAzz
//		|associationColorArray[]
//			Key:cellColorTable.jsŒ`ꂽFIDB(:hdrRedAhdrRedSelected)
//			Value:F̒l(:#ffffff)
// *************************************************************************************************

// ============== ZI ==================================================
	var previousClickedCell = null;		// OIꂽZ̃IuWFNg
	var coloredCellList  = new ActiveXObject("Scripting.Dictionary"); // FÂς݂̃ZXg(Key:id,Value:Object)
	var selectedCellList = new ActiveXObject("Scripting.Dictionary"); // IԂ̃ZXg(Key:id,Value:Object)

	// |[gɃZ݂ȂߐFÂłȂZi[B
	// iZN^ŊOꂽAړŃ|[g\ωȂǂ̏ꍇɔj
	var disableHdrColorString = "";	// wb_
	var disableDtColorString  = "";	// Spreade[u

//	var selectedPrefix = "selected"; 	// I𒆂\X^Cɂړ
	var selectedSuffix = "Selected";	// I𒆂\X^Cɂڔ

	// *********************************************************
	//  C֐
	// *********************************************************

	// ZIꂽ(ZNbNCxg)
	function cellClicked() {

		var node = null;// sEwb_̃Z(TD)
		if ( event.srcElement.tagName == "TD" ) {
			node = event.srcElement;
		} else if ( event.srcElement.tagName == "NOBR" ) {
			node = event.srcElement.parentNode;
		} else {
			return; 
		}

		if ( node.id == "adjustCell" ) { return; }	// adjustCell̏ꍇ͏Ȃ

		// ύX̏ꍇAZI͎sȂ
		if ( changedColRange ) { 
			changedColRange = false;
			return; 
		}

		// ONbNꂽZƓZNbNFIσZNAAI
		// ONbNꂽZƈႤZNbNFIσZNAANbNꂽZI
		if ( previousClickedCell != null ) {
			if ( previousClickedCell.id == node.id ) {
				clearSelectedCell();
				return;
			} else {
				clearSelectedCell();
			}
		}

		// IԂɂZ̃X^CύX
		applyColorStyleToCell ( node );

		// NbNꂽZI܂ŉۑ
		previousClickedCell = node;

	}


	// Iς݂̃ZɎw肳ꂽFX^Cݒ肷
	// input: colorStyle : F\X^C
	function setColorToSelectedCell ( colorName ) {
		if ( previousClickedCell == null ) { return; }

		var dicArray = (new VBArray(selectedCellList.Keys())).toArray();
		if ( dicArray.length == 0 ) { return; }

		var node;
		for( var i = 0; i < dicArray.length; i++) {

			node = selectedCellList.Item(dicArray[i]);

			// FÂ
			paintCellColor( node, colorName );

			// FÂς݂̃ZidXgXV
			if( coloredCellList.Exists(node.id) ) { //FÂĂ
				if ( colorName == "" ) { //pbgŁuhԂȂvIꂽ
					coloredCellList.Remove( node.id );
				}
			} else { // FÂĂȂ
				if ( colorName != "" ) { // FX^Cݒ
					coloredCellList.add( node.id, node );
				}
			}

		}

		// 
		previousClickedCell = null;
		selectedCellList = new ActiveXObject("Scripting.Dictionary");
	}

	// *********************************************************
	//  X^C֐iwb_Af[^e[uj
	// *********************************************************

	// NbNꂽZɂAύXΏۃZ̃X^CύXs
	function applyColorStyleToCell( ele ) {

		// NbNꂽZFf[^e[ũZZ̐FύX
		if ( getCellPosition( ele ) == "DATA" ) {
			setColorStyle( ele );
			return;
		}

		// NbNꂽZFEswb_[̃Zwb_AΉf[^e[u̗Es̐FύX
		changeHeaderCellsStyle(ele);		// wb_
		changeDataTableCellsStyle( ele );	// f[^e[u
	}

	// wb_Z̃X^CύX
	function changeHeaderCellsStyle( node ) {

		var hieIndex = getHieIndex(node);

		// ̒i
		setColorStyle(node);

		// |Pi
		if (( getHeaderObjNum(getCellPosition(node)) >= 2 ) && ( !isLastHie(node) )) {
			var childCells = getUnderHieNodes(node);
			for ( var i = 0; i < childCells.length; i++ ) {
				setColorStyle(childCells[i]);
			}

			// |Qi
			if (( getHeaderObjNum(getCellPosition(node)) == 3 ) && ( hieIndex == 0 )) {
				var grandChilds = getUnder2HieNodes(node);
				for ( var i = 0; i < grandChilds.length; i++ ) {
					setColorStyle(grandChilds[i]);
				}
			}
		}
	}

	// f[^e[uZ̃X^CύX
	// 	targetNode: FCOLIuWFNgAsFTRIuWFNg
	// 	ele:  NbNꂽIuWFNgis/̃ZTDj
	function changeDataTableCellsStyle( ele ) {
		var target = getSpreadNodeByTDObj( ele );
		var loopMax = getDataTableCellNumbers( getCellPosition ( ele ) ); // ̗/sZ
		var targetEdge = getCellPosition(ele); // COL or ROW

		for ( var i = 0; i < getLowerHieComboNum( ele, getCellPosition(ele) ); i++ ) {//Iꂽ/s̃[v
			var index = 0;	// ̗/sIndex
			if ( isCellInColHeader(ele) ) {
				index = parseInt( getCOLIndexByCOLObj(target) );
			} else if ( isCellInRowHeader(ele) ) {
				index = parseInt( getRowIndexByTRObj(target) );
			}

			var x,y;
			for ( var j = 0; j < loopMax; j++ ) {	//̗/sZ郋[v
				// ZW̎Zo
				if ( targetEdge == "COL" ) {
					x = index;
					y = j;
				} else if ( targetEdge == "ROW" ) {
					x = j;
					y = index;
				}
				// Z̐FÂ
				setColorStyle ( dataTable.rows(y).cells(x) );
			}

			target = target.nextSibling;
		}
	}

	// *********************************************************
	//  X^C֐iZj
	// *********************************************************

	// Iς݃Z̃X^C
	function clearSelectedCell ( ) {

		if ( previousClickedCell == null ) { return; }
		var dicArray = (new VBArray(selectedCellList.Keys())).toArray();
		if ( dicArray.length == 0 ) { return; }

		var node;
		for( var i = 0; i < dicArray.length; i++) {
			node = selectedCellList(dicArray[i]);
			makeUnSelectedColor(node);
		}

		// 
		previousClickedCell = null;
		selectedCellList.RemoveAll();
	}


	// F̃X^Cݒ肷
	function setColorStyle( node ) {

		makeSelectedColor( node );
		if( !selectedCellList.Exists(node.id) ) {
			selectedCellList.add( node.id, node );	// Iς݂̃ZidXgɒǉ
		}
	}

	// *********************************************************
	//  ZX^CύX֐
	// *********************************************************

	// ^ꂽZ̃X^CIԂ֕ύX
	// 	input	: IuWFNg(sAAf[^e[ũZiTD))
	function makeSelectedColor( ele ) {
		if ( ele == null ) { return; }
		if ( ele.tagName != "TD") { return; }
		if ( ele.selected == "1" ) { return; } // IԂ̃Złreturn

		var prefix = null;
		if (getCellPosition(ele) == "DATA") {
			prefix = "dt";
		} else {
			prefix = "hdr";
		}

		// FÂĂȂZIԂɂ
		ele.selected  = "1";
		if ( ele.colorName == null ) { 
			ele.style.backgroundColor = associationColorArray[prefix + selectedSuffix];

		// FÂĂZIԂɂ
		} else {
			ele.style.backgroundColor = associationColorArray[prefix + ele.colorName + selectedSuffix];
		}

	}

	// ^ꂽZ̃X^CIԂ֕ύX
	function makeUnSelectedColor( ele ) {
		if ( ele == null ) { return; }
		if ( ele.tagName != "TD") { return; }
		if ( ele.selected == "0" ) { return; } // IԂ̃ZłȂreturn

		var prefix = null;
		if (getCellPosition(ele) == "DATA") {
			prefix = "dt";
		} else {
			prefix = "hdr";
		}

		// Iς݂̐FI̐F
		ele.selected = "0";
		if ( ele.colorName == null ) { // FÂĂȂZ
			ele.style.backgroundColor = "";
		} else {// FÂĂZ
			ele.style.backgroundColor = associationColorArray[prefix + ele.colorName];
		}
	}

	// ZFt
	function paintCellColor( ele, colorName ) {
		if ( ele == null ) { return; }
		if ( ele.tagName != "TD") { return; }
		if ( colorName == null ) { return; }

		// FÂ
		ele.selected = "0";
		if ( colorName == "" ) { //pbgŁuhԂȂvIꂽ
			ele.removeAttribute("colorName");
			ele.style.backgroundColor = "";
		} else {
			var target = getCellPosition(ele);
			var prefix = null;
			if (target == "DATA") {
				prefix = "dt";
			} else {
				prefix = "hdr";
			}
			ele.colorName = colorName;
			ele.style.backgroundColor = associationColorArray[prefix + colorName];
		}

	}

	// *********************************************************
	//  FÂ擾֐
	// *********************************************************

	// ݂̐Fݒ擾iZI̓NAj
	// return:	String[]
	//        	String[0]:wb_̐F , String[1]:{fB̐F
	// 			Fid.key:id.key:id.key:id.key:id.key:id.key;color
	//			 id.key̓wb_ZFRȓAf[^ZFUȓ
	function getColorArray() {

		// IԂ̃Z̑IAFIO̐Fɖ߂B
		if ( previousClickedCell != null ) {
			clearSelectedCell();
		}

		var dtColorInfo = "";
		var hdrColorInfo = "";

		var dicArray = ( new VBArray( coloredCellList.Keys() )).toArray();	// FÂĂZXg
		var disableHdrColor = disableHdrColorString;	//FÂs\łwb_[Z
		var disableDtColor  = disableDtColorString;		//FÂs\łe[uZ

		if ( ( dicArray.length == 0 ) && ( disableHdrColorString == "" ) && ( disableDtColorString == "" ) ) { return null; }

		var node;
		var str;
		for( var i = 0; i < dicArray.length; i++ ) {
			node = coloredCellList( dicArray[i] );
			str = "";
			if ( isCellInDataTable(node) ) { // f[^e[u̐F
				str = getIdKeyList( node, "COL" ) + ":" + getIdKeyList( node, "ROW" ) + ";" + node.colorName;
				if ( dtColorInfo == "" ) {
					dtColorInfo = str;
				} else {
					dtColorInfo += "," + str;
				}
			} else { // wb_̐F

				if ( isLastHie(node) ) { // orsŉĩIuWFNg
					if ( isCellInColHeader( node ) ) {
						str = getIdKeyList( node, "COL" ) + ";" + node.colorName;
					} else if ( isCellInRowHeader( node ) ) {
						str = getIdKeyList( node, "ROW" ) + ";" + node.colorName;
					}
				} else { // ors̍ŉiȊO̐F͕ۑȂiFÂɃWbNŐj
					continue;
				}

				if ( hdrColorInfo == "" ) {
					hdrColorInfo = str;
				} else {
					hdrColorInfo += "," + str;
				}
			}
		}


		// disable̒ǉ(FÂꂽZȂ)
			if ( (hdrColorInfo != "")  && (disableHdrColor != "") ) {
				disableHdrColor = "," + disableHdrColor;
			}
			if ( (dtColorInfo != "") && (disableDtColor != "") ) {
				disableDtColor = "," + disableDtColor;
			}

		var returnArray = new Array(1);
		returnArray[0] = hdrColorInfo + disableHdrColor;
		returnArray[1] = dtColorInfo  + disableDtColor;

		// disablȅ
		disableHdrColorString = "";
		disableDtColorString  = "";

		return returnArray;
	}

	// F擾
	function getColorIndexInfoArray () {

		// IԂ̃Z̑IAFIO̐Fɖ߂B
		if ( previousClickedCell != null ) {
			clearSelectedCell();
		}

		var dicArray = ( new VBArray( coloredCellList.Keys() )).toArray();	// FÂĂZXg
		if ( dicArray.length == 0 ) { return null; }

		var colArray = new Array();
		var rowArray = new Array();
		var dataArray = new Array();
		var colIndex = 0;
		var rowIndex = 0;
		var dataIndex = 0;


		for( var i = 0; i < dicArray.length; i++ ) {
			node = coloredCellList( dicArray[i] );
			var tmpString = getSpreadCoordinate(node) + ";" + node.colorName;
			if ( getCellPosition( node ) == "COL" ) {
				colArray[colIndex]= tmpString;
				colIndex++;
			} else if ( getCellPosition( node ) == "ROW" ) {
				rowArray[rowIndex] = tmpString;
				rowIndex++;
			} else if ( getCellPosition( node ) == "DATA" ) {
				dataArray[dataIndex] = tmpString;
				dataIndex++;
			}
		}

		var colorIndexInfoArray = new Array(3);
			colorIndexInfoArray[0] = colArray.join(",");
			colorIndexInfoArray[1] = rowArray.join(",");
			colorIndexInfoArray[2] = dataArray.join(",");

		return colorIndexInfoArray;

	}


	// *********************************************************
	//  Z擾֐
	// *********************************************************


	// w肳ꂽwb_̎ID,o[L[̑gݍ킹̑gݍ킹擾
	// <Input>  node  : s/wb_ TDIuWFNg
	//          target: COL or ROW
	// <Output> s/̒iIDEKEY̑gݍ킹
	//		         hie0 : hie1 : hie2
	//		        ---------------------
	//		   col: id.key:id.key:id.key
	//		   row: id.key:id.key:id.key
	function getIdKeyList( node, target ) {

		if ( ( node == null ) || ( target == null ) || ( target == "" ) ) { return null;}

		var idKeyArray = new Array();

		if ( target == "COL" ) {
			var indexNode = document.getElementById( "CH_CG" + getColIndexByTDObj( node ) );
			var objNum = colObjNum;
		} else if ( target == "ROW" ) {
			var indexNode = document.getElementById( "RH_R" + getRowIndexByTRObj( node.parentNode ) );
			var objNum = rowObjNum;
		}

		var oAxis;
		for ( var i = 0; i < objNum; i++ ) {
			if ( i == 0 ) { // ŉi
				oAxis = getCellObj( indexNode, target, (objNum - 1) );
			} else {
				oAxis = getUpperCellObject( oAxis, target );
			}
			idKeyArray[i] = getHieID( (objNum - 1 - i), target) + "." + oAxis.key;
		}

		idKeyArray.reverse();
		return idKeyArray.join(":");
	}

==> OpenOLAP_V1.2.0.zip: OpenOLAP/src/viewer/target/spread/js/cellColor.js <==

// *************************************************************************************************
// FẪf[^\
//	EZ(TDIuWFNg)̑
//		<TD object>.selected: ZIĂ"1"AIĂȂ"0"BԂł͑ȂB
//		<TD object>.colorName: ZɂĂF̖(FuRedv,uPurplevetc)
//		<TD object>.style.backgroundColor: ۂɃZɂĂFiAzz擾j 
//	EAzz
//		|associationColorArray[]
//			Key:cellColorTable.jsŒ`ꂽFIDB(:hdrRedAhdrRedSelected)
//			Value:F̒l(:#ffffff)
// *************************************************************************************************

// ============== ZI ==================================================
	var previousClickedCell = null;		// OIꂽZ̃IuWFNg
	var coloredCellList  = new ActiveXObject("Scripting.Dictionary"); // FÂς݂̃ZXg(Key:id,Value:Object)
	var selectedCellList = new ActiveXObject("Scripting.Dictionary"); // IԂ̃ZXg(Key:id,Value:Object)

	// |[gɃZ݂ȂߐFÂłȂZi[B
	// iZN^ŊOꂽAړŃ|[g\ωȂǂ̏ꍇɔj
	var disableHdrColorString = "";	// wb_
	var disableDtColorString  = "";	// Spreade[u

//	var selectedPrefix = "selected"; 	// I𒆂\X^Cɂړ
	var selectedSuffix = "Selected";	// I𒆂\X^Cɂڔ

	// *********************************************************
	//  C֐
	// *********************************************************

	// ZIꂽ(ZNbNCxg)
	function cellClicked() {

		//nCCg̏ꍇ͐FÂłȂ
		if(parent.display_area.document.all.tblHigtLightBtn.style.display=="block"){
			return;
		}



		var node = null;// sEwb_̃Z(TD)
		if ( event.srcElement.tagName == "TD" ) {
			node = event.srcElement;
		} else if ( event.srcElement.tagName == "NOBR" ) {
			node = event.srcElement.parentNode;
		} else {
			return; 
		}

		if ( node.id == "adjustCell" ) { return; }	// adjustCell̏ꍇ͏Ȃ

		// ύX̏ꍇAZI͎sȂ
		if ( changedColRange ) { 
			changedColRange = false;
			return; 
		}

		// ONbNꂽZƓZNbNFIσZNAAI
		// ONbNꂽZƈႤZNbNFIσZNAANbNꂽZI
		if ( previousClickedCell != null ) {
			if ( previousClickedCell.id == node.id ) {
				clearSelectedCell();
				return;
			} else {
				clearSelectedCell();
			}
		}

		// IԂɂZ̃X^CύX
		applyColorStyleToCell ( node );

		// NbNꂽZI܂ŉۑ
		previousClickedCell = node;

	}


	// Iς݂̃ZɎw肳ꂽFX^Cݒ肷
	// input: colorStyle : F\X^C
	function setColorToSelectedCell ( colorName ) {
		if ( previousClickedCell == null ) { return; }

		var dicArray = (new VBArray(selectedCellList.Keys())).toArray();
		if ( dicArray.length == 0 ) { return; }

		var node;
		for( var i = 0; i < dicArray.length; i++) {

			node = selectedCellList.Item(dicArray[i]);

			// FÂ
			paintCellColor( node, colorName );

			// FÂς݂̃ZidXgXV
			if( coloredCellList.Exists(node.id) ) { //FÂĂ
				if ( colorName == "" ) { //pbgŁuhԂȂvIꂽ
					coloredCellList.Remove( node.id );
				}
			} else { // FÂĂȂ
				if ( colorName != "" ) { // FX^Cݒ
					coloredCellList.add( node.id, node );
				}
			}

		}

		// 
		previousClickedCell = null;
		selectedCellList = new ActiveXObject("Scripting.Dictionary");
	}

	// *********************************************************
	//  X^C֐iwb_Af[^e[uj
	// *********************************************************

	// NbNꂽZɂAύXΏۃZ̃X^CύXs
	function applyColorStyleToCell( ele ) {

		// NbNꂽZFf[^e[ũZZ̐FύX
		if ( getCellPosition( ele ) == "DATA" ) {
			setColorStyle( ele );
			return;
		}

		// NbNꂽZFEswb_[̃Zwb_AΉf[^e[u̗Es̐FύX
		changeHeaderCellsStyle(ele);		// wb_
		changeDataTableCellsStyle( ele );	// f[^e[u
	}

	// wb_Z̃X^CύX
	function changeHeaderCellsStyle( node ) {

		var hieIndex = getHieIndex(node);

		// ̒i
		setColorStyle(node);

		// |Pi
		if (( getHeaderObjNum(getCellPosition(node)) >= 2 ) && ( !isLastHie(node) )) {
			var childCells = getUnderHieNodes(node);
			for ( var i = 0; i < childCells.length; i++ ) {
				setColorStyle(childCells[i]);
			}

			// |Qi
			if (( getHeaderObjNum(getCellPosition(node)) == 3 ) && ( hieIndex == 0 )) {
				var grandChilds = getUnder2HieNodes(node);
				for ( var i = 0; i < grandChilds.length; i++ ) {
					setColorStyle(grandChilds[i]);
				}
			}
		}
	}

	// f[^e[uZ̃X^CύX
	// 	targetNode: FCOLIuWFNgAsFTRIuWFNg
	// 	ele:  NbNꂽIuWFNgis/̃ZTDj
	function changeDataTableCellsStyle( ele ) {
		var target = getSpreadNodeByTDObj( ele );
		var loopMax = getDataTableCellNumbers( getCellPosition ( ele ) ); // ̗/sZ
		var targetEdge = getCellPosition(ele); // COL or ROW

		for ( var i = 0; i < getLowerHieComboNum( ele, getCellPosition(ele) ); i++ ) {//Iꂽ/s̃[v
			var index = 0;	// ̗/sIndex
			if ( isCellInColHeader(ele) ) {
				index = parseInt( getCOLIndexByCOLObj(target) );
			} else if ( isCellInRowHeader(ele) ) {
				index = parseInt( getRowIndexByTRObj(target) );
			}

			var x,y;
			for ( var j = 0; j < loopMax; j++ ) {	//̗/sZ郋[v
				// ZW̎Zo
				if ( targetEdge == "COL" ) {
					x = index;
					y = j;
				} else if ( targetEdge == "ROW" ) {
					x = j;
					y = index;
				}
				// Z̐FÂ
				setColorStyle ( dataTable.rows(y).cells(x) );
			}

			target = target.nextSibling;
		}
	}

	// *********************************************************
	//  X^C֐iZj
	// *********************************************************

	// Iς݃Z̃X^C
	function clearSelectedCell ( ) {

		if ( previousClickedCell == null ) { return; }
		var dicArray = (new VBArray(selectedCellList.Keys())).toArray();
		if ( dicArray.length == 0 ) { return; }

		var node;
		for( var i = 0; i < dicArray.length; i++) {
			node = selectedCellList(dicArray[i]);
			makeUnSelectedColor(node);
		}

		// 
		previousClickedCell = null;
		selectedCellList.RemoveAll();
	}


	// F̃X^Cݒ肷
	function setColorStyle( node ) {

		makeSelectedColor( node );
		if( !selectedCellList.Exists(node.id) ) {
			selectedCellList.add( node.id, node );	// Iς݂̃ZidXgɒǉ
		}
	}

	// *********************************************************
	//  ZX^CύX֐
	// *********************************************************

	// ^ꂽZ̃X^CIԂ֕ύX
	// 	input	: IuWFNg(sAAf[^e[ũZiTD))
	function makeSelectedColor( ele ) {
		if ( ele == null ) { return; }
		if ( ele.tagName != "TD") { return; }
		if ( ele.selected == "1" ) { return; } // IԂ̃Złreturn

		var prefix = null;
		if (getCellPosition(ele) == "DATA") {
			prefix = "dt";
		} else {
			prefix = "hdr";
		}

		// FÂĂȂZIԂɂ
		ele.selected  = "1";
		if ( ele.colorName == null ) { 
			ele.style.backgroundColor = associationColorArray[prefix + selectedSuffix];

		// FÂĂZIԂɂ
		} else {
			ele.style.backgroundColor = associationColorArray[prefix + ele.colorName + selectedSuffix];
		}

	}

	// ^ꂽZ̃X^CIԂ֕ύX
	function makeUnSelectedColor( ele ) {
		if ( ele == null ) { return; }
		if ( ele.tagName != "TD") { return; }
		if ( ele.selected == "0" ) { return; } // IԂ̃ZłȂreturn

		var prefix = null;
		if (getCellPosition(ele) == "DATA") {
			prefix = "dt";
		} else {
			prefix = "hdr";
		}

		// Iς݂̐FI̐F
		ele.selected = "0";
		if ( ele.colorName == null ) { // FÂĂȂZ
			ele.style.backgroundColor = "";
		} else {// FÂĂZ
			ele.style.backgroundColor = associationColorArray[prefix + ele.colorName];
		}
	}

	// ZFt
	function paintCellColor( ele, colorName ) {
		if ( ele == null ) { return; }
		if ( ele.tagName != "TD") { return; }
		if ( colorName == null ) { return; }

		// FÂ
		ele.selected = "0";
		if ( colorName == "" ) { //pbgŁuhԂȂvIꂽ
			ele.removeAttribute("colorName");
			ele.style.backgroundColor = "";
		} else {
			var target = getCellPosition(ele);
			var prefix = null;
			if (target == "DATA") {
				prefix = "dt";
			} else {
				prefix = "hdr";
			}
			ele.colorName = colorName;
			ele.style.backgroundColor = associationColorArray[prefix + colorName];
			ele.orgBColor = associationColorArray[prefix + colorName];
		}

	}

	// *********************************************************
	//  FÂ擾֐
	// *********************************************************

	// ݂̐Fݒ擾iZI̓NAj
	// return:	String[]
	//        	String[0]:wb_̐F , String[1]:{fB̐F
	// 			Fid.key:id.key:id.key:id.key:id.key:id.key;color
	//			 id.key̓wb_ZFRȓAf[^ZFUȓ
	function getColorArray() {

		// IԂ̃Z̑IAFIO̐Fɖ߂B
		if ( previousClickedCell != null ) {
			clearSelectedCell();
		}

		var dtColorInfo = "";
		var hdrColorInfo = "";

		var dicArray = ( new VBArray( coloredCellList.Keys() )).toArray();	// FÂĂZXg
		var disableHdrColor = disableHdrColorString;	//FÂs\łwb_[Z
		var disableDtColor  = disableDtColorString;		//FÂs\łe[uZ

		if ( ( dicArray.length == 0 ) && ( disableHdrColorString == "" ) && ( disableDtColorString == "" ) ) { return null; }

		var node;
		var str;
		for( var i = 0; i < dicArray.length; i++ ) {
			node = coloredCellList( dicArray[i] );
			str = "";
			if ( isCellInDataTable(node) ) { // f[^e[u̐F
				str = getIdKeyList( node, "COL" ) + ":" + getIdKeyList( node, "ROW" ) + ";" + node.colorName;
				if ( dtColorInfo == "" ) {
					dtColorInfo = str;
				} else {
					dtColorInfo += "," + str;
				}
			} else { // wb_̐F

				if ( isLastHie(node) ) { // orsŉĩIuWFNg
					if ( isCellInColHeader( node ) ) {
						str = getIdKeyList( node, "COL" ) + ";" + node.colorName;
					} else if ( isCellInRowHeader( node ) ) {
						str = getIdKeyList( node, "ROW" ) + ";" + node.colorName;
					}
				} else { // ors̍ŉiȊO̐F͕ۑȂiFÂɃWbNŐj
					continue;
				}

				if ( hdrColorInfo == "" ) {
					hdrColorInfo = str;
				} else {
					hdrColorInfo += "," + str;
				}
			}
		}


		// disable̒ǉ(FÂꂽZȂ)
			if ( (hdrColorInfo != "")  && (disableHdrColor != "") ) {
				disableHdrColor = "," + disableHdrColor;
			}
			if ( (dtColorInfo != "") && (disableDtColor != "") ) {
				disableDtColor = "," + disableDtColor;
			}

		var returnArray = new Array(1);
		returnArray[0] = hdrColorInfo + disableHdrColor;
		returnArray[1] = dtColorInfo  + disableDtColor;

		// disablȅ
		disableHdrColorString = "";
		disableDtColorString  = "";

		return returnArray;
	}

	// F擾
	function getColorIndexInfoArray () {

		// IԂ̃Z̑IAFIO̐Fɖ߂B
		if ( previousClickedCell != null ) {
			clearSelectedCell();
		}

		var dicArray = ( new VBArray( coloredCellList.Keys() )).toArray();	// FÂĂZXg
		if ( dicArray.length == 0 ) { return null; }

		var colArray = new Array();
		var rowArray = new Array();
		var dataArray = new Array();
		var colIndex = 0;
		var rowIndex = 0;
		var dataIndex = 0;


		for( var i = 0; i < dicArray.length; i++ ) {
			node = coloredCellList( dicArray[i] );
			var tmpString = getSpreadCoordinate(node) + ";" + node.colorName;
			if ( getCellPosition( node ) == "COL" ) {
				colArray[colIndex]= tmpString;
				colIndex++;
			} else if ( getCellPosition( node ) == "ROW" ) {
				rowArray[rowIndex] = tmpString;
				rowIndex++;
			} else if ( getCellPosition( node ) == "DATA" ) {
				dataArray[dataIndex] = tmpString;
				dataIndex++;
			}
		}

		var colorIndexInfoArray = new Array(3);
			colorIndexInfoArray[0] = colArray.join(",");
			colorIndexInfoArray[1] = rowArray.join(",");
			colorIndexInfoArray[2] = dataArray.join(",");

		return colorIndexInfoArray;

	}


	// *********************************************************
	//  Z擾֐
	// *********************************************************


	// w肳ꂽwb_̎ID,o[L[̑gݍ킹̑gݍ킹擾
	// <Input>  node  : s/wb_ TDIuWFNg
	//          target: COL or ROW
	// <Output> s/̒iIDEKEY̑gݍ킹
	//		         hie0 : hie1 : hie2
	//		        ---------------------
	//		   col: id.key:id.key:id.key
	//		   row: id.key:id.key:id.key
	function getIdKeyList( node, target ) {

		if ( ( node == null ) || ( target == null ) || ( target == "" ) ) { return null;}

		var idKeyArray = new Array();

		if ( target == "COL" ) {
			var indexNode = document.getElementById( "CH_CG" + getColIndexByTDObj( node ) );
			var objNum = colObjNum;
		} else if ( target == "ROW" ) {
			var indexNode = document.getElementById( "RH_R" + getRowIndexByTRObj( node.parentNode ) );
			var objNum = rowObjNum;
		}

		var oAxis;
		for ( var i = 0; i < objNum; i++ ) {
			if ( i == 0 ) { // ŉi
				oAxis = getCellObj( indexNode, target, (objNum - 1) );
			} else {
				oAxis = getUpperCellObject( oAxis, target );
			}
			idKeyArray[i] = getHieID( (objNum - 1 - i), target) + "." + oAxis.key;
		}

		idKeyArray.reverse();
		return idKeyArray.join(":");
	}
